pub fn split_after<T, F>(src: Source<T>, pred: F) -> Source<Source<T>>where T: Send + 'static, F: FnMut(&T) -> bool + Send + 'static,
split_after(pred) — like split_when, except the splitting element stays with the previous substream and the next element starts a new one.
split_after(pred)
split_when