pub struct InstantToken(pub u64);Expand description
Opaque, monotonically increasing token identifying an emitted instant from
step_locked. Consumers ack an element by sending its token back through
the AckSink.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for InstantToken
impl Clone for InstantToken
Sourcefn clone(&self) -> InstantToken
fn clone(&self) -> InstantToken
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstantToken
impl Debug for InstantToken
Sourceimpl Hash for InstantToken
impl Hash for InstantToken
Sourceimpl Ord for InstantToken
impl Ord for InstantToken
Sourcefn cmp(&self, other: &InstantToken) -> Ordering
fn cmp(&self, other: &InstantToken) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InstantToken
impl PartialEq for InstantToken
Sourcefn eq(&self, other: &InstantToken) -> bool
fn eq(&self, other: &InstantToken) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for InstantToken
impl PartialOrd for InstantToken
impl Copy for InstantToken
impl Eq for InstantToken
impl StructuralPartialEq for InstantToken